@@ -23,14 +23,41 @@ module Elasticsearch
   module RestAPIYAMLTests
     module WipeCluster
       PRESERVE_ILM_POLICY_IDS = [
-        'ilm-history-ilm-policy', 'slm-history-ilm-policy', 'watch-history-ilm-policy',
-        'watch-history-ilm-policy-16', 'ml-size-based-ilm-policy', 'logs', 'metrics', 'profiling',
-        'synthetics', '7-days-default', '30-days-default', '90-days-default', '180-days-default',
-        '365-days-default', '.fleet-files-ilm-policy', '.fleet-file-data-ilm-policy',
-        '.fleet-actions-results-ilm-policy', '.fleet-file-fromhost-data-ilm-policy',
-        '.fleet-file-fromhost-meta-ilm-policy', '.fleet-file-tohost-data-ilm-policy',
-        '.fleet-file-tohost-meta-ilm-policy', '.deprecation-indexing-ilm-policy',
-        '.monitoring-8-ilm-policy', 'behavioral_analytics-events-default_policy',
+        'ilm-history-ilm-policy',
+        'slm-history-ilm-policy',
+        'watch-history-ilm-policy',
+        'watch-history-ilm-policy-16',
+        'ml-size-based-ilm-policy',
+        'logs',
+        'logs@lifecycle',
+        'metrics',
+        'metrics@lifecycle',
+        'profiling-60-days',
+        'profiling-60-days@lifecycle',
+        'synthetics',
+        'agentless',
+        'synthetics@lifecycle',
+        'traces@lifecycle',
+        '7-days-default',
+        '7-days@lifecycle',
+        '30-days-default',
+        '30-days@lifecycle',
+        '90-days-default',
+        '90-days@lifecycle',
+        '180-days-default',
+        '180-days@lifecycle',
+        '365-days-default',
+        '365-days@lifecycle',
+        '.fleet-files-ilm-policy',
+        '.fleet-file-data-ilm-policy',
+        '.fleet-actions-results-ilm-policy',
+        '.fleet-file-fromhost-data-ilm-policy',
+        '.fleet-file-fromhost-meta-ilm-policy',
+        '.fleet-file-tohost-data-ilm-policy',
+        '.fleet-file-tohost-meta-ilm-policy',
+        '.deprecation-indexing-ilm-policy',
+        '.monitoring-8-ilm-policy',
+        'behavioral_analytics-events-default_policy',
         'logs-apm.app_logs-default_policy',
         'logs-apm.error_logs-default_policy',
         'metrics-apm.app_metrics-default_policy',
@@ -414,24 +441,27 @@ module Elasticsearch
         def clear_ml_jobs(client)
           client.ml.close_job(job_id: '_all', force: true)
           client.ml.get_jobs['jobs'].each do |d|
-            client.ml.delete_job(job_id: d['job_id'])
+            client.ml.delete_job(job_id: d['job_id'], wait_for_completion: false, force: true)
           end
         end
 
         def clear_datafeeds(client)
           client.ml.stop_datafeed(datafeed_id: '_all', force: true)
           client.ml.get_datafeeds['datafeeds'].each do |d|
-            client.ml.delete_datafeed(datafeed_id: d['datafeed_id'])
+            Thread.new do
+              client.ml.stop_datafeed(datafeed_id: d['datafeed_id'], force: true)
+              client.ml.delete_datafeed(datafeed_id: d['datafeed_id'], force: true)
+            rescue StandardError
+              logger.info('Exception deleting datafeed')
+            end
           end
         end
 
         def clear_tasks(client)
           tasks = client.tasks.get['nodes'].values.first['tasks'].values.select do |d|
             d['cancellable']
-          end.map do |d|
-            "#{d['node']}:#{d['id']}"
           end
-          tasks.each { |t| client.tasks.cancel task_id: t }
+          tasks.each { |d| client.tasks.cancel(task_id: "#{d['node']}:#{d['id']}") }
         end
 
         def clear_machine_learning_indices(client)
@@ -448,7 +478,7 @@ module Elasticsearch
 
         def clear_transforms(client)
           client.transform.get_transform(transform_id: '*')['transforms'].each do |transform|
-            client.transform.delete_transform(transform_id: transform['id'])
+            client.transform.delete_transform(transform_id: transform['id'], force: true)
           end
         end
 
