@@ -20,26 +20,16 @@ require 'spec_helper'
 describe 'client#fleet.search' do
   let(:expected_args) do
     [
-      'GET',
+      'POST',
       'foo/_fleet/_fleet_search',
       {},
-      nil,
+      {},
       {},
       { defined_params: { index: 'foo' }, endpoint: 'fleet.search' }
     ]
   end
 
   it 'performs the request' do
-    expect(client_double.fleet.search(index: 'foo')).to be_a Elasticsearch::API::Response
-  end
-
-  let(:client) do
-    Class.new { include Elasticsearch::API }.new
-  end
-
-  it 'requires the :index argument' do
-    expect {
-      client.fleet.search
-    }.to raise_exception(ArgumentError)
+    expect(client_double.fleet.search(index: 'foo', body: {})).to be_a Elasticsearch::API::Response
   end
 end
